==> kafka-3.7.2-src.tgz: kafka-3.7.2-src/metadata/src/main/java/org/apache/kafka/image/node/DelegationTokenImageNode.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.kafka.image.node;

import org.apache.kafka.image.DelegationTokenImage;
import org.apache.kafka.metadata.DelegationTokenData;

import java.util.Collection;

public class DelegationTokenImageNode implements MetadataNode {
    /**
     * The name of this node.
     */
    public final static String NAME = "delegationToken";

    /**
     * The DelegationToken image.
     */
    private final DelegationTokenImage image;

    public DelegationTokenImageNode(DelegationTokenImage image) {
        this.image = image;
    }

    @Override
    public Collection<String> childNames() {
        return image.tokens().keySet();
    }

    @Override
    public MetadataNode child(String tokenId) {
        DelegationTokenData data = image.tokens().get(tokenId);
        if (data == null) return null;
        return new DelegationTokenDataNode(data);
    }
}

==> kafka-3.9.0-src.tgz: kafka-3.9.0-src/metadata/src/main/java/org/apache/kafka/image/node/DelegationTokenImageNode.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.kafka.image.node;

import org.apache.kafka.image.DelegationTokenImage;
import org.apache.kafka.metadata.DelegationTokenData;

import java.util.Collection;

public class DelegationTokenImageNode implements MetadataNode {
    /**
     * The name of this node.
     */
    public static final String NAME = "delegationToken";

    /**
     * The DelegationToken image.
     */
    private final DelegationTokenImage image;

    public DelegationTokenImageNode(DelegationTokenImage image) {
        this.image = image;
    }

    @Override
    public Collection<String> childNames() {
        return image.tokens().keySet();
    }

    @Override
    public MetadataNode child(String tokenId) {
        DelegationTokenData data = image.tokens().get(tokenId);
        if (data == null) return null;
        return new DelegationTokenDataNode(data);
    }
}
